@@ -15,7 +15,7 @@ class Api():
         hentaifox (str): The base url of hentaifox api.
         hentai2read (str): The base url of hentai2read api.
     """
-    with open('janda/base/Base.json', 'r', encoding='utf-8') as f:
+    with open('Base.json', 'r', encoding='utf-8') as f:
         nh = json.load(f)
 
     def __init__(self,
